#include "CMyWindow.h"

#include <QAction>
#include <QDesktopWidget>
#include <QSettings>



CMyWindow::CMyWindow(QWidget* parent) : QWidget(parent) {
	QAction* action = new QAction("toggle fullScreen", this);
	action->setShortcut(QString("Ctrl+F"));
	connect(action, SIGNAL(triggered()), SLOT(toggleFullScreen()));
	addAction(action);

	QSettings settings;
	restoreGeometry(settings.value("geometry").toByteArray());
};



CMyWindow::~CMyWindow() {
	QSettings settings;
	settings.setValue("geometry", saveGeometry());
};



/*	I want to move a window from screen 0 to screen 1 in fullscreen state,
	screen 0 has different resolution than screen 1.
*/
void CMyWindow::moveToScreen(int screen) {
	// window is on screen 0 in fullscreen state
	// screen == 1

	QDesktopWidget desktop;
	if (desktop.screenCount() <= screen) return;
	// screenCount returns 2

	QRect screenGeometry = desktop.availableGeometry(screen);
	bool fullScreen = this->isFullScreen();
	bool maximized = this->isMaximized();
	// screenGeometry is corrent
	// fullScreen == true

	if (fullScreen || maximized) this->showNormal();
	// window is on screen 0 in normal state

	QRect geometry = this->geometry();
	geometry.moveCenter(screenGeometry.center());
	this->setGeometry(geometry);
	// window is on screen 1 in normal state

	if (fullScreen) this->showFullScreen();
	if (maximized) this->showMaximized();
	// Window is on screen 0 in fullscreen state.
	// BUG, it must be on screen 1, but it is on screen 0 somehow.

	// bug walkaround
	if (fullScreen) {
		this->showNormal();
		this->showFullScreen();
	};
	// window is on screen 1 in fullscreen state
};



void CMyWindow::toggleFullScreen() {
	isFullScreen() ? showNormal() : showFullScreen();
};


